'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/**
 * Throw error when something goes wrong
 * @param input value is an invalid input privided by user in function
 * @param requiredType required type of value to be inputed
 * @returns {string}
 */
function throwError(input, requiredType) {
  if (requiredType === void 0) {
    requiredType = 'string';
  }

  var error = {
    error: "Invalid parameter type. \n '" + input + "' must be type '" + requiredType + "'"
  };
  console.error(error);
  return error.error;
}

/**
 *
 * @param str1 first string.
 * @param str2 second string.
 * @returns boolean
 * @description checks whether the first string equals to the second string.
 *
 * @example```javascript
 * console.log(areEqual("user","use")) //false
 * console.log(areEqual("user","user")) //true
 * ```
 */

function areEqual(str1, str2) {
  if (typeof str1 !== 'string' || typeof str2 !== 'string') {
    throwError(typeof str1 !== 'string' ? str1 : str2, 'string');
    return false;
  }

  return str1 === str2;
}

/**
 *
 * @param str1 first string.
 * @param str2 second string.
 * @returns boolean
 * @description checks whether the first string equals to the second string but ignoring the cases.
 *
 * @example```javascript
 * console.log(areEqualIgnoreCase("user","use")) //false
 * console.log(areEqualIgnoreCase("user","User")) //true
 * ```
 */

function areEqualIgnoreCase(str1, str2) {
  if (typeof str1 !== 'string' || typeof str2 !== 'string') {
    throwError(typeof str1 !== 'string' ? str1 : str2, 'string');
    return false;
  }

  return str1.toLowerCase() === str2.toLowerCase();
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description capitalizes the string.
 *
 * @example```javascript
 * console.log(capitalize("mY sTring")) //My String
 * console.log(capitalize("MY STRING","user")) //My String
 * ```
 */

function capitalize(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';

  if (str.length < 0) {
    return str;
  }

  return str.trim().toLowerCase().replace(/\w\S*/g, function (w) {
    return w.replace(/^\w/, function (c) {
      return c.toUpperCase();
    });
  });
}

/**
 *
 * @param (str1,str2,str3,...) provided string.
 * @returns boolean
 * @description compares many strings.
 *
 * @example```javascript
 * console.log(compareMany('string1', 'string2', 'string3')) //false
 * console.log(compareMany('string1', 'string1', 'string1')) //true
 * ```
 */
function compareMany() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  args = [].concat(args);
  if (args.length === 0) return false;
  var equal = true;
  args.forEach(function (element) {
    if (args[0] !== element) equal = false;
  });
  return equal;
}

/**
 *
 * @param (str1,str2,str3,...) provided string.
 * @returns boolean
 * @description compares many strings ignoring case.
 *
 * @example```javascript
 * console.log(compareManyIgnoreCase('string1', 'string2', 'string3')) //false
 * console.log(compareManyIgnoreCase('String1', 'string1', 'string1')) //true
 * ```
 */
function compareManyIgnoreCase() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  args = [].concat(args);
  if (args.length === 0) return false;
  var equal = true;
  args.forEach(function (element) {
    if (args[0].toLowerCase() !== element.toLowerCase()) equal = false;
  });
  return equal;
}

/**
 *
 * @param str provided string.
 * @param substr provided substring.
 * @returns boolean
 * @description checks whether a substring is in the provided string.
 *
 * @example```javascript
 * console.log(contains('coding is fun', 'is')) //true
 * console.log(contains('coding is fun', 'Coding')) //false
 * ```
 */
function contains(str, substr) {
  if (typeof str !== 'string' || typeof substr !== 'string') {
    throwError(typeof str !== 'string' ? str : substr, 'string');
    return false;
  }

  return str.indexOf(substr) > -1;
}

/**
 *
 * @param str provided string.
 * @param search provided search value.
 * @returns number
 * @description checks the number of times a search occurs in a string.
 *
 * @example```javascript
 * console.log(count('number of times', 'of')) //1
 * console.log(count('number of times', ' ')) //2
 * ```
 */
function count(str, search) {
  if (typeof str !== 'string' || typeof search !== 'string') {
    throwError(typeof str !== 'string' ? str : search, 'string');
    return -1;
  }

  var strLen = str.length;
  var searchLen = search.length;
  var res = 0;

  for (var i = 0; i <= strLen - searchLen; i++) {
    var j = void 0;

    for (j = 0; j < searchLen; j++) {
      if (str[i + j] !== search[j]) {
        break;
      }
    }

    if (j === searchLen) {
      res++;
      j = 0;
    }
  }

  return res;
}

/**
 *
 * @param str whose to check words.
 * @returns number
 * @description returns number of words in provided string.
 *
 * @example```javascript
 * console.log(countWords('str')) //1
 * console.log(countWords('hello there')) //2
 * console.log(countWords('data lmn dsad das')) //4
 * ```
 */

function countWords(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return -1;
  }

  return str.split(' ').length;
}

/**
 *
 * @param str whose words are.
 * @returns number
 * @description returns number of spaces in a string.
 *
 * @example```javascript
 * console.log(countSpaces('str')) //0
 * console.log(countSpaces('hello there')) //1
 * ```
 */

function countSpaces(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return -1;
  }

  return countWords(str) - 1;
}

/**
 *
 * @param str to chech spaces.
 * @returns boolean
 * @description checks whether provided string has spaces or not.
 *
 * @example```javascript
 * console.log(hasSpaces('str')) //false
 * console.log(hasSpaces('hello there')) //true
 * console.log(hasSpaces('data lmn dsad das')) //true
 * ```
 */

function hasSpaces(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  return countSpaces(str) > 0;
}

/**
 *
 * @param str to check vowels.
 * @returns number
 * @description returns number of vowels in provided string.
 *
 * @example```javascript
 * console.log(countVowels('string1')) //1
 * console.log(countVowels('stringaa')) //3
 * console.log(countVowels('strng')) //0
 * ```
 */

function countVowels(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return -1;
  }

  return Array.from(str).filter(function (letter) {
    return 'aeiou'.includes(letter);
  }).length;
}

/**
 *
 * @param str1 Bigger string.
 * @param str2 Smaller string to check if contained in  str1.
 * @returns boolean
 * @description checks whether the first string starts with the second.
 *
 * @example```javascript
 * console.log(startsWith('manila', 'man')) //true
 * console.log(startsWith('data science', 'data')) //true
 * console.log(startsWith('manstring', 'String1')) //false
 *
 * ```
 */
function startsWith(str1, str2) {
  if (typeof str1 !== 'string' || typeof str2 !== 'string') {
    throwError(typeof str1 !== 'string' ? str1 : str2, 'string');
    return false;
  }

  return str1.startsWith(str2);
}

/**
 *
 * @param str provided string.
 * @returns number
 * @description returns number of consonants in a string provided.
 *
 * @example```javascript
 * console.log(countConsonants('str')) //3
 * console.log(countConsonants('stringaa')) //5
 * console.log(countConsonants('aiue')) //0
 * ```
 */
function countConsonants(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return -1;
  }

  return Array.from(str).filter(function (letter) {
    return 'qwrtypsdfghjklzxcvbnm'.includes(letter);
  }).length;
}

/**
 *
 * @param str provided string.
 * @returns object
 * @description checks occurences of each character in a string.
 *
 * @example```javascript
 * console.log(countCharacters('oreste')) //{ o: 1, r: 1, e: 2, s: 1, t: 1 }
 * console.log(countCharacters('ooo')) //{ o: 3 }
 * ```
 */

function countCharacters(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    var c = {};
    return c;
  }

  var count = {};
  str.split('').forEach(function (_char) {
    count[_char] = count[_char] ? count[_char] + 1 : 1;
  });
  return count;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);

  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }

  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function isCharacterALetter(_char) {
  return /[a-zA-Z]/.test(_char);
}

/**
 *
 * @param str provided string.
 * @returns boolean
 * @description checks whether all string characters are alphabetical characters.
 *
 * @example```javascript
 * console.log(isAlpha('')) //false
 * console.log(isAlpha('hello')) //true
 * console.log(isAlpha('hello123')) //false
 * ```
 */

function isAlpha(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  var AlphaFound = false;
  var nonAlphaFound = true;

  for (var _iterator = _createForOfIteratorHelperLoose(str), _step; !(_step = _iterator()).done;) {
    var character = _step.value;
    if (isCharacterALetter(character)) AlphaFound = true;else nonAlphaFound = false;
  }

  return AlphaFound && nonAlphaFound;
}

function isCharacterAlphaNumeric(ch) {
  return ch.match(/^[a-z0-9]+$/i) !== null;
}

/**
 *
 * @param str provided string.
 * @returns boolean
 * @description checks whether all string characters are alphanumeric characters.
 *
 * @example```javascript
 * console.log(isAlphaNumeric('')) //false
 * console.log(isAlphaNumeric('hello')) //true
 * console.log(isAlphaNumeric('hello123')) //true
 * console.log(isAlphaNumeric('hello ')) //false
 * ```
 */

function isAlphaNumeric(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  var AlphaNumericFound = false;
  var nonAlphaNumericFound = true;

  for (var _iterator = _createForOfIteratorHelperLoose(str), _step; !(_step = _iterator()).done;) {
    var character = _step.value;
    if (isCharacterAlphaNumeric(character)) AlphaNumericFound = true;else nonAlphaNumericFound = false;
  }

  return AlphaNumericFound && nonAlphaNumericFound;
}

/**
 *
 * @param str provided string.
 * @returns boolean
 * @description checks whether all string characters are digits.
 *
 * @example```javascript
 * console.log(isDigit('')) //false
 * console.log(isDigit('hello')) //false
 * console.log(isDigit('123')) //true
 * console.log(isDigit('hello123')) //false
 * ```
 */

function isDigit(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  if (str.includes(' ')) return false;
  return !isNaN(parseFloat(str));
}

/**
 *
 * @param str provided string.
 * @returns boolean
 * @description checks whether a string is empty or not.
 *
 * @example```javascript
 * console.log(isEmpty('')) //true
 * console.log(isEmpty('hello')) //false
 *
 * ```
 */
function isEmpty(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  return str.length === 0;
}

/**
 *
 * @param str provided string.
 * @returns boolean
 * @description checks whether a string is lowercase.
 *
 * @example```javascript
 * console.log(isLowerCase('mY sTring')) //false
 * console.log(isLowerCase('my string')) //true
 *
 * ```
 */

function isLowerCase(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  return str !== str.toUpperCase() && str === str.toLowerCase();
}

/**
 *
 * @param str provided string.
 * @param separator optional
 * @returns boolean
 * @description checks whether a string is palindrome.
 *
 * @example```javascript
 * console.log(isPalindrome('string')) //false
 * console.log(isPalindrome('s/t/r/i/n/g', '/')) //false
 * console.log(isPalindrome('A Santa Lived As a Devil At NASA')) //true
 * console.log(isPalindrome('A-Santa-Lived-As-a-Devil-At-NASA', '-')) //true
 *
 * ```
 */

function isPalindrome(str, separator) {
  if (separator === void 0) {
    separator = ' ';
  }

  if (typeof str !== 'string' || typeof separator !== 'string') {
    throwError(typeof str !== 'string' ? str : separator, 'string');
    return false;
  }

  str = str.split(separator).join('').toLowerCase();
  var palindrome = true; // find the length of a string

  var len = str.length; // loop through half of the string

  for (var i = 0; i < len / 2; i++) {
    // check if first and last string are same
    if (str[i] !== str[len - 1 - i]) {
      palindrome = false;
    }
  }

  return palindrome;
}

function isSpace(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  var spaceFound = false;
  var nonSpaceFound = true;

  for (var _iterator = _createForOfIteratorHelperLoose(str), _step; !(_step = _iterator()).done;) {
    var character = _step.value;
    if (character === ' ') spaceFound = true;else nonSpaceFound = false;
  }

  return spaceFound && nonSpaceFound;
}

/**
 *
 * @param str provided string.
 * @returns boolean
 * @description checks whether a string is uppercase.
 *
 * @example```javascript
 * console.log(isUpperCase('mY sTring')) //false
 * console.log(isUpperCase('MY STRING')) //true
 *
 * ```
 */

function isUpperCase(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  return str === str.toUpperCase() && str !== str.toLowerCase();
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description checks the sorted longest combination of strings.
 *
 * @example```javascript
 * console.log(longestCombination('oreste', 'abizera')) //abeiorstz
 *
 * ```
 */
function longestCombination() {
  for (var _len = arguments.length, params = new Array(_len), _key = 0; _key < _len; _key++) {
    params[_key] = arguments[_key];
  }

  return [].concat(new Set(params.join('').toLowerCase())).sort().join('');
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description removes duplicate words from a string.
 *
 * @example```javascript
 * console.log(removeDuplicates('print print hello')) //print hello
 * console.log(removeDuplicates('hello')) //hello
 *
 * ```
 */
function removeDuplicates(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  return [].concat(new Set(str.split(' '))).join(' ');
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description reverses a string
 *
 * @example```javascript
 * console.log(reverse('str║ing')) //gni║rts
 * console.log(reverse('s_t_r_i_n_g', '_')) //g_n_i_r_t_s
 *
 * ```
 */

function reverse(str, separator) {
  if (separator === void 0) {
    separator = '';
  }

  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  return str.trim().split(separator).reverse().join(separator);
}

/**
 *
 * @param str provided string.
 * @param separator optional
 * @returns string
 * @description reverses a string words
 *
 * @example```javascript
 * console.log(reverseWord('Oreste Abizera')) //Abizera Oreste
 * console.log(reverseWord('Oreste_Abizera', '_')) //Abizera Oreste
 *
 * ```
 */

function reverseWord(str, separator) {
  if (separator === void 0) {
    separator = ' ';
  }

  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  return str.trim().split(separator).reverse().join(separator);
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description creates a slug for a string
 *
 * @example```javascript
 * console.log(slugify('my favorite poem')) //my-favorite-poem
 *
 * ```
 */
function slugify(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  return str.split(' ').join('-');
}

function splitMulti(str, tokens) {
  var tempChar = tokens[0]; // We can use the first token as a temporary join character

  var result;

  for (var i = 1; i < tokens.length; i++) {
    str = str.split(tokens[i]).join(tempChar);
  }

  result = str.split(tempChar);
  return result;
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description converts a string to camelcase
 *
 * @example```javascript
 * console.log(toCamelCase('PascalCase')) //pascalCase
 * console.log(toCamelCase(' Train-Case')) //trainCase
 * console.log(toCamelCase('to-camel_case case')) //toCamelCaseCase
 *
 * ```
 */

function toCamelCase(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  var symbols = ['-', '_', ' '];
  str = isUpperCase(str) ? str.trim() : str.trim().replace(/^\w/, function (c) {
    return c.toLowerCase();
  });
  var current = splitMulti(str, symbols);

  if (current.length > 1) {
    current.forEach(function (element, index) {
      element = element.toLowerCase();
      current[index] = index === 0 ? element : element.replace(/^\w/, function (c) {
        return c.toUpperCase();
      });
    });
    str = current.join('');
  }

  return str;
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description returns letters of a string with its repetition times.
 *
 * @example```javascript
 * console.log(countRepetitions('userrr')) //1u1s1e3r
 * console.log(countRepetitions('')) //[Empty String]
 * ```
 */

function countRepetitions(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  var result = '';
  var count = 1;

  for (var i = 0; i < str.length; i++) {
    if (str[i + 1] !== str[i]) {
      result += "" + count + str[i];
      count = 1;
    } else {
      count++;
    }
  }

  return result;
}

function changeCase(_char) {
  return _char.toLowerCase() === _char ? _char.toUpperCase() : _char.toLowerCase();
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description changes a string to alternate case
 *
 * @example```javascript
 * console.log(toAlternatingCase('hello world')) //HELLO WORLD
 * console.log(toAlternatingCase('hello WORLD')) //HELLO world
 * console.log(toAlternatingCase('1a2b3c4d5e')) //1A2B3C4D5E
 *
 * ```
 */

function toAlternatingCase(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  return str.split('').map(function (_char) {
    return changeCase(_char);
  }).join('');
}

function isPreposition(word) {
  var prepositions = ['of', 'the'];
  return prepositions.includes(word.toLowerCase());
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description converts a string to title case considering prepositions
 *
 * @example```javascript
 * console.log(toTitleCase('the return of john')) //The Return of John
 * console.log(toTitleCase('THE RETURN OF JOHN')) //The Return of John
 * console.log(toTitleCase('tHe retuRn OF jOhn')) //The Return of John
 *
 * ```
 */

function toTitleCase(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  var words = str.split(' ');

  for (var i = 0; i < words.length; i++) {
    var word = words[i];
    if (i > 0 && isPreposition(word)) words[i] = words[i].toLowerCase();else words[i] = capitalize(word);
  }

  return words.join(' ');
}

/**
 *
 * @param str provided string.
 * @returns string
 * @description returns a new string from a provided string without any space.
 *
 * @example```javascript
 * console.log(removeSpaces(" t od a y")) //today
 * console.log(removeSpaces("   😀   😁    😂   ")) //😀😁😂
 * ```
 */

function removeSpaces(str) {
  if (typeof str !== 'string') {
    return throwError(str, 'string');
  }

  if (!str) return '';
  return str.split(' ').join('');
}

/**
 *
 * @param str provided string.
 * @returns boolean
 * @description returns true if the provided string contains one or more emojis and else if no emoji is found in the provided string.
 *
 * @example```javascript
 * console.log(containsEmoji("hello world")) //false
 * console.log(containsEmoji("")) //false
 * console.log(containsEmoji("hello 😀")) //true
 * ```
 */

function containsEmoji(str) {
  if (typeof str !== 'string') {
    throwError(str, 'string');
    return false;
  }

  var regexExp = /(\u00a9|\u00ae|[\u2000-\u3300]|\ud83c[\ud000-\udfff]|\ud83d[\ud000-\udfff]|\ud83e[\ud000-\udfff])/gi;
  return regexExp.test(str);
}

exports.areEqual = areEqual;
exports.areEqualIgnoreCase = areEqualIgnoreCase;
exports.capitalize = capitalize;
exports.compareMany = compareMany;
exports.compareManyIgnoreCase = compareManyIgnoreCase;
exports.contains = contains;
exports.containsEmoji = containsEmoji;
exports.count = count;
exports.countCharacters = countCharacters;
exports.countConsonants = countConsonants;
exports.countRepetitions = countRepetitions;
exports.countSpaces = countSpaces;
exports.countVowels = countVowels;
exports.countWords = countWords;
exports.hasSpaces = hasSpaces;
exports.isAlpha = isAlpha;
exports.isAlphaNumeric = isAlphaNumeric;
exports.isDigit = isDigit;
exports.isEmpty = isEmpty;
exports.isLowerCase = isLowerCase;
exports.isPalindrome = isPalindrome;
exports.isSpace = isSpace;
exports.isUpperCase = isUpperCase;
exports.longestCombination = longestCombination;
exports.removeDuplicates = removeDuplicates;
exports.removeSpaces = removeSpaces;
exports.reverse = reverse;
exports.reverseWord = reverseWord;
exports.slugify = slugify;
exports.startsWith = startsWith;
exports.toAlternatingCase = toAlternatingCase;
exports.toCamelCase = toCamelCase;
exports.toTitleCase = toTitleCase;
//# sourceMappingURL=string-method.cjs.development.js.map
